=============================
 ``zope.filerepresentation``
=============================

.. image:: https://img.shields.io/pypi/v/zope.filerepresentation.svg
        :target: https://pypi.python.org/pypi/zope.filerepresentation/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.filerepresentation.svg
        :target: https://pypi.org/project/zope.filerepresentation/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.filerepresentation.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.filerepresentation

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.filerepresentation/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.filerepresentation?branch=master

.. image:: https://readthedocs.org/projects/zopefilerepresentation/badge/?version=latest
        :target: https://zopefilerepresentation.readthedocs.io/en/latest/
        :alt: Documentation Status


The interfaces defined here are used for file-system and file-system-like
representations of objects, such as file-system synchronization, FTP, PUT, and
WebDAV.

Documentation is hosted at https://zopefilerepresentation.readthedocs.io/
